server_client_20141211_231026

zopkio

- Summary
- Results
  - config1
    - test_negative_correctness
    - test_client_isolation
    - test_bouncing_with_state
    - test_multi_client_perf
    - test_client_timeout
    - test_race_condition
    - test_fault_tolerance
    - test_redlining
    - test_single_client_perf
    - test_ordered_events
    - test_correctness
    - test_load_balance
  - config2
    - test_negative_correctness
    - test_client_isolation
    - test_bouncing_with_state
    - test_multi_client_perf
    - test_client_timeout
    - test_race_condition
    - test_fault_tolerance
    - test_redlining
    - test_single_client_perf
    - test_ordered_events
    - test_correctness
    - test_load_balance
- Diff
- Logs

### Test Summary

Total tests | Total passed | Total failed | Total skipped | Total execution time
--- | --- | --- | --- | ---
24 | 8 | 16 | 0 | 314.878565073 sec

###

Configuration name | Skipped? | Has failures? | Has skipped?
--- | --- | --- | ---
config1 | No | Yes | No
config2 | No | Yes | No